import {myBridge,previewMapBridge} from "./map.js";
import {getMapToken,getServiceToken} from "../../service/map.js";


// 白膜颜色配置
const locationRenderer = {
    type: "simple",
    symbol: {
        type: "mesh-3d",
        symbolLayers: [{
            type: "fill",
            material: {
                color: [255, 255, 255, 1],
                colorMixMode: "tint"
            },
            edges: {
                type: 'solid',
                color: [0, 0, 0, 0.5],
                size: 1
            }
        }]
    }
};
export function invokeParams(ActionName,params){
    getMapToken().then(res =>{
        let token = res.data.msg[0].Rows[0].token;
        myBridge.bridgeContent.Invoke({
            'ActionName': ActionName,
            "Parameters": {
                token: token,
                ...params
            }
        })
    })
}
export function previewInvokeParams(ActionName, params) {
    getMapToken().then(res =>{
        let token = res.data.msg[0].Rows[0].token;
        previewMapBridge.bridgeContent.Invoke({
            'ActionName': ActionName,
            "Parameters": {
                token: token,
                ...params
            }
        })
    })
}

async function returnProxyUrl(url){
    let arr = url.split('/');
    let username = '';
    let password = '';
    debugger
    if(arr.indexOf('MapProxyApi') !== -1){ //不需要授权服务
        for(let i=0;i<arr.length;i++){
            if(arr[i] ==='getSceneServer'){
                username = arr[i+1];
                password = arr[i+2];
                const response = await getServiceToken(username,password);
                if(response?.data.length > 0){
                    arr.splice(i-1, 4);
                    return arr.join('/')+'/MapServiceProxy/'+response.data;
                }
            }
        }
    }else{
        return url
    }
}

export function SetBackground(){
    invokeParams('SetBackground', {
        "opacity": 1,
        "color": "transparent",
    })
}

export function AddWhiteMold(visible){
    invokeParams('AddSingleLayer', {
        "id": "D8503010320240901",
        "title": "全市白模",
        "visible": visible,
        "opacity": 0.4,
        "renderer":locationRenderer,
        "url": "https://cimweb.zjw.sh.cegn.cn:2008/MapProxyApi/getSceneServer/ptgl/05195418",
        "type": "scene",
    })
}
export function addPartWhiteMold(visible){
    invokeParams('AddSingleLayer', {
        "id": "whiteMold",
        "title": "局部白模",
        "visible": visible,
        "opacity": 0,
        "renderer":locationRenderer,
        //"url":"https://serve3d41.gis.cn:6443/geoscene/rest/services/Hosted/jzbm_ljz/SceneServer",
        "url": "https://cimweb.zjw.sh.cegn.cn:2008/MapProxyApi/getSceneServer/gxjh_fwjk/D9999990120240926",
        "type": "scene",
    })
}

export function GroundPrismEffect(params){
    invokeParams('GroundPrismEffect', {
        "status": params.status,
        "startHeight":params.startHeight,
        "rings": [
            [
                [
                    2283.1137006787776,
                    636.1578526852668
                ],
                [
                    2755.442842863678,
                    1026.8816302796026
                ],
                [
                    3531.034281735133,
                    1248.901078489329
                ],
                [
                    4264.864482789166,
                    1262.6133470962304
                ],
                [
                    4846.072870575944,
                    1220.3100790217377
                ],
                [
                    5349.2761417332795,
                    1254.9545222719507
                ],
                [
                    5489.116295834501,
                    849.424842489057
                ],
                [
                    5680.445379537043,
                    447.08383557562183
                ],
                [
                    5897.983788255289,
                    -72.23287029218955
                ],
                [
                    5353.235081713489,
                    -314.4967403232263
                ],
                [
                    4880.7215573706435,
                    -446.1705186078343
                ],
                [
                    4419.945274186343,
                    -620.6697712028126
                ],
                [
                    4022.245846137783,
                    -798.2234781410284
                ],
                [
                    3588.865915776516,
                    -1016.6756351545175
                ],
                [
                    3308.344794632267,
                    -716.4720188261422
                ],
                [
                    2995.5705887037257,
                    -401.75745444376344
                ],
                [
                    2660.6207445233986,
                    -59.444218653938606
                ],
                [
                    2377.4465865885672,
                    212.6415896605945
                ],
                [
                    2272.8639529375205,
                    442.8097125262784
                ],
                [
                    2283.1137006787776,
                    636.1578526852668
                ]
            ]
        ],
        "items": params.items
    })
}

export function ExtentGridPrismEffect(params){
    invokeParams('ExtentGridPrismEffect', {
        "status": params.status,
        "size":params.size,
        "rings": [
            [
                [
                    2283.1137006787776,
                    636.1578526852668
                ],
                [
                    2755.442842863678,
                    1026.8816302796026
                ],
                [
                    3531.034281735133,
                    1248.901078489329
                ],
                [
                    4264.864482789166,
                    1262.6133470962304
                ],
                [
                    4846.072870575944,
                    1220.3100790217377
                ],
                [
                    5349.2761417332795,
                    1254.9545222719507
                ],
                [
                    5489.116295834501,
                    849.424842489057
                ],
                [
                    5680.445379537043,
                    447.08383557562183
                ],
                [
                    5897.983788255289,
                    -72.23287029218955
                ],
                [
                    5353.235081713489,
                    -314.4967403232263
                ],
                [
                    4880.7215573706435,
                    -446.1705186078343
                ],
                [
                    4419.945274186343,
                    -620.6697712028126
                ],
                [
                    4022.245846137783,
                    -798.2234781410284
                ],
                [
                    3588.865915776516,
                    -1016.6756351545175
                ],
                [
                    3308.344794632267,
                    -716.4720188261422
                ],
                [
                    2995.5705887037257,
                    -401.75745444376344
                ],
                [
                    2660.6207445233986,
                    -59.444218653938606
                ],
                [
                    2377.4465865885672,
                    212.6415896605945
                ],
                [
                    2272.8639529375205,
                    442.8097125262784
                ],
                [
                    2283.1137006787776,
                    636.1578526852668
                ]
            ]
        ],
        "items": [
            {
                "id": 1,
                "name": "",
                "depth": 1000,
                "material": [
                    151,220,252,
                    0.2
                ]
            }
        ]
    })
}


export async function PrismEffectService_sfky(params) {
    let url = await returnProxyUrl("https://cimweb.zjw.sh.cegn.cn:2008/MapProxyApi/getSceneServer/gxjh_fwjk/D9999990220240926") + '/1';
    invokeParams('PrismEffectService', {
        "status": params.status,
        "id": "sfky",
        "opacity": 0.6,
        "height": 120,
        "url":url,
        //"url": "https://serve2d31.gis.cn:6443/geoscene/rest/services/dkjj/dknew/MapServer/1",
        "material": [
            4, 138, 255,
            1
        ]
    })
}

export async function PrismEffectService_jkbhq(params) {
    let url = await returnProxyUrl("https://cimweb.zjw.sh.cegn.cn:2008/MapProxyApi/getSceneServer/gxjh_fwjk/D9999990220240926") + '/0';
    invokeParams('PrismEffectService', {
        "status": params.status,
        "id": "jkbhq",
        "opacity": 0.6,
        "height": 1000,
        "url":url,
        //"url": "https://serve2d31.gis.cn:6443/geoscene/rest/services/dkjj/dknew/MapServer/0",
        "material": [
            255, 0, 0,
            1
        ]
    })
}

export async function WaterEffect(params) {
    let url = await returnProxyUrl("https://cimweb.zjw.sh.cegn.cn:2008/MapProxyApi/getSceneServer/gxjh_fwjk/D0401010120150601") + '/0';
    invokeParams('WaterEffect', {
        "status": params.status,
        "url": url,
        "direction": 260,
        "strength": "moderate",
        "color": "#25427c"
    })
}


export function LimitHeightAnalysis(params){
    invokeParams('LimitHeightAnalysis', {
        "status":params.status,
        "distance":params.start,
        "distanceEnd":params.end,
        "rings":  [
            [
                [
                    2283.1137006787776,
                    636.1578526852668
                ],
                [
                    2755.442842863678,
                    1026.8816302796026
                ],
                [
                    3531.034281735133,
                    1248.901078489329
                ],
                [
                    4264.864482789166,
                    1262.6133470962304
                ],
                [
                    4846.072870575944,
                    1220.3100790217377
                ],
                [
                    5349.2761417332795,
                    1254.9545222719507
                ],
                [
                    5489.116295834501,
                    849.424842489057
                ],
                [
                    5680.445379537043,
                    447.08383557562183
                ],
                [
                    5897.983788255289,
                    -72.23287029218955
                ],
                [
                    5353.235081713489,
                    -314.4967403232263
                ],
                [
                    4880.7215573706435,
                    -446.1705186078343
                ],
                [
                    4419.945274186343,
                    -620.6697712028126
                ],
                [
                    4022.245846137783,
                    -798.2234781410284
                ],
                [
                    3588.865915776516,
                    -1016.6756351545175
                ],
                [
                    3308.344794632267,
                    -716.4720188261422
                ],
                [
                    2995.5705887037257,
                    -401.75745444376344
                ],
                [
                    2660.6207445233986,
                    -59.444218653938606
                ],
                [
                    2377.4465865885672,
                    212.6415896605945
                ],
                [
                    2272.8639529375205,
                    442.8097125262784
                ],
                [
                    2283.1137006787776,
                    636.1578526852668
                ]
            ]
        ],
        "maxNode":3
    })
}


//重点区域定位
export function importantAreaPosition(x,y,z,heading,tilt,isfly=true){
    invokeParams('SetLocation',{
        "x": x,
        "y": y,
        "z": z,
        "heading": heading,
        "tilt": tilt,
        "isfly": isfly
    })
}

export function FeatureThreeDimension(params){
    debugger
    if(params.token){
        params.url = "https://cimweb.zjw.sh.cegn.cn:2008/MapServiceProxy/" + params.token;
    }
    invokeParams('FeatureThreeDimension', {
        "url": params.url,
        "status": params.status
    })
}

//区县聚类
export function MapClickByType(status){
    invokeParams('MapClickAll', {
        "status": status,
        "disableLayerIdList":["districtArea","districtStreet","bgFeaturelayer"]
    })
}

//点查询
export function AreaJsonRankShow(params){
    debugger
    invokeParams('AreaJsonRankShow', {
        "type": params.type,  //qx、jz
        "district": null,
        "id": "AreaTextLayer",
        "title": "文本标绘",
        "status": params.status,
        "data": params.data,
        "symbol": {
            "color": [255, 255, 255, 1],
            "backgroundColor": [77, 161, 194, 0.4],
            "font": {
                "size": 12
            }
        },
    })
}

export async function AddBaseMapLayer() {
    let url = await returnProxyUrl("https://cimweb.zjw.sh.cegn.cn:2008/MapProxyApi/getSceneServer/ptgl/93493321");
    console.log("1111",url);
    debugger
    invokeParams('AddBaseMapLayer', {
        "id": "BaseMap",
        "title": "BaseMap",
        "visible": true,
        "opacity": 1,
        url
    })
}

export async function AddZhenwuMapLayer() {
    let url = await returnProxyUrl("https://cimweb.zjw.sh.cegn.cn:2008/MapProxyApi/getSceneServer/ptgl/37072265");
    console.log("1111",url);
    debugger
    invokeParams('AddBaseMapLayer', {
        "id": "BaseMapZhenwu",
        "title": "BaseMapZhenwu",
        "visible": true,
        "opacity": 1,
        url
    })
}

export async function AddYaoganMapLayer() {
    let url = await returnProxyUrl("https://cimweb.zjw.sh.cegn.cn:2008/MapProxyApi/getSceneServer/ptgl/50115036");
    console.log("1111",url);
    debugger
    invokeParams('AddBaseMapLayer', {
        "id": "BaseMapYaoGan",
        "title": "BaseMapYaoGan",
        "visible": true,
        "opacity": 1,
        "type": "tile",
       url
    })
}

//关闭图层
export function clearAllLayer() {
    invokeParams('ClearMapLayers',{
    })
}


export function AddSingleLayer(params){
    debugger;
    if(params.token){
        params.url = "https://cimweb.zjw.sh.cegn.cn:2008/MapServiceProxy/" + params.token;
    }
    let wkid = "0"  // 0 代表上海城建 1：代表3857
    if(params.wkid){
        if(params.type == "动态地图" && params.wkid =="1"){
            params.type = "dynamic"
        }
        if(params.type == "切片地图" && params.wkid =="1"){
            params.type = "tile"
        }
    }

    if(params.type=="scene"||params.type=='3DObject'){
        invokeParams('AddSingleLayer', {
            "id": params.id,
            "title": params.title,
            "visible": params.visible,
            "opacity": 0.4,
            "url": params.url,
            "type": "scene",
            "renderer":locationRenderer,
            "mapID": params.mapID
        })
    }
    else if(params.type=="bim"){
        switch (params.title) {
            case '朱家角车站':
                invokeParams('AddSingleLayer',
                    {
                        "id": params.id,
                        "title": params.title,
                        "visible": params.visible,
                        "opacity": params.opacity === undefined?1:params.opacity,
                        "url": params.url,
                        "elevationInfo": {   //下沉高度
                            mode:"absolute-height",
                            offset:-19.5
                        },
                        "type": "building",
                        "mapID": params.mapID
                    })
                break;
            default:
                invokeParams('AddSingleLayer',
                    {
                        "id": params.id,
                        "title": params.title,
                        "visible": params.visible,
                        "opacity": params.opacity === undefined?1:params.opacity,
                        "url": params.url,
                        "elevationInfo": {   //下沉高度
                            mode:"absolute-height",
                            offset:-19.5
                        },
                        "type": "building",
                        "mapID": params.mapID
                    })
                break
        }
    }
    else if(params.type=='mesh'){
        invokeParams('AddSingleLayer',
            {
                "id": params.id,
                "title": params.title,
                "visible": params.visible,
                "opacity": params.opacity === undefined?1:params.opacity,
                "url": params.url,
                //"renderer":locationRenderer,
                "type": "mesh",
                "mapID": params.mapID
            })
        return
    }
    else if(params.type=="dynamic"){
        invokeParams('AddSingleLayer', {
            "id": params.id,
            "title": params.title,
            "visible": params.visible,
            "opacity": params.opacity === undefined?1:params.opacity,
            "url": params.url,
            // "sublayers": [
            //     {
            //         "id": 0
            //     },{
            //         "id": 1
            //     }
            // ],
            "type": "dynamic",
            "mapID": params.mapID
        })
    }
    else if(params.type=="tile"){
        invokeParams('AddSingleLayer', {
            "id": params.id,
            "title": params.title,
            "visible": params.visible,
            "opacity": params.opacity === undefined?1:params.opacity,
            "url": params.url,
            "type": "tile",
            "mapID": params.mapID
        })
    }else if(params.type=="动态地图"){
        invokeParams('AddSingleLayer', {
            "id": params.id,
            "title": params.title,
            "visible": params.visible,
            "opacity": params.opacity === undefined?1:params.opacity,
            "url": params.url,
            "type": "shc_map",
            "mapID": params.mapID
        })
    }else if(params.type=="切片地图"){
        let size = [256,256];
        let origin = {
            "x": -9080400.0,
            "y": 10002300
        };
        invokeParams('AddSingleLayer',
            {
                "id": params.id,
                "title": params.title,
                "visible": params.visible,
                "opacity": params.opacity === undefined?1:params.opacity,
                "url": params.url,
                "type": "shc_tile",
                "mapID": params.mapID
            })
    }
}